% FUNKCIJA ZA PRIKAZ REZULTATOV ANALIZE PREREZA

% fukncija narie:
% zvezo med momentom in zasukom
%   -idealizacija oznaci kriticne tocke
%   -superpozicija odziva jeklene armature
%   -primerjava dveh rezultatov
% zvezo med napetostjo v relevantnih betonskih vlaknih in ukrivljenostjo
% zvezo med napetostjo v relevantnih armaturnih vlaknih in ukrivljenostjo

% VHODNI PARAMETRI
% i...         ...zaporedna tevilka preizkuanca v moji bazi
% BazaParametrov..moja baza parametrov, ki vsebuje izmerjeno ovojnico
% Rezultati1......struktura s rezultati funkcije "A1analiza_prerezov.m"
% MPhi...      ...ali natisne odvisnost M-phi: MPhi=1 ->da / MPhi=0 ->ne
% Rezultati2......struktura s rezultati, ki jo elimo primerjati s Rezulati1
%                 -e Rezultati2=strutura -> naredi superpozicijo rezultatov
%                 kjer so rezultati2 obarvani s rno barvo
%                 -e Rezultati2=0 program ne naredi niesar
% KritToAnal......1->da / 0->ne
%                 -zelena navpina rtkana linija oznauje z analizo dobljen zasuk na meji teenja armature
%                 -rdea navpina rtkana linija oznauje z analizo dobljen zasuk na zaetku ruenja betonskega jedra
% KritToMer... ...1->da / 0->ne
%                 -zelena navpina polna linija oznauje z meritvami dobljen zasuk na meji teenja armature
%                 -rdea navpina polna linija oznauje z meritvami dobljen zasuk na zaetku ruenja betonskega jedra
% Ideal...     ...1->da / 0->ne
%                 -narie idealizirano zvezo M-phi
% SupArm...    ...1->da / 0->ne
%                 -narie superpozicijo napetosti v armaturi, ki ni v merilu, za boljo predstavo dogajanja v prerezu
% CPhi...      ...1->da / 0->ne
%                 -ali natisne graf s zvezami med napetostjo v posameznih betonskih lamelah in ukrivljenostjo prereza
%                 napetosti merimo v 9 tokah po betonskem jedru. Na grafu so krivulje obarvane od rdee za najbolj tlaeno vlakno
%                 do modre na drugi strani.
%                 -rdea debela krivulja predstavlja napetosti v najbolj tlaenem vlaknu krovnega sloja
% APhi...      ...1->da / 0->ne
%                 - -ali natisne graf s zvezami med   natzno napetostjo v jekleni armaturi s oznaeno mejo teenja
             
             
function Korak=A4kontrolaRezultatov(i,BazaParametrov,Rezultati1,MPhi,Rezultati2,KritToAnal,KritToMer,Ideal,SupArm,CPhi,APhi)

% PARAMETRI UPORABLJENI PRI IZGRADNJI FUNKCIJE

if MPhi==1;
    
    %PLOT - M-Phi
    figure
    if not(length(Rezultati2)==1)
        fi2=Rezultati2(i).fi;
        fi2(1)=[];
        
        
        % zveza med moemtnom in ukrivljenostjo iz analize prereza brez uklona
        Cur2=Rezultati2(i).fi;
        M12=Rezultati2(i).M1;
        
        plot(Cur2,M12,'k:','LineWidth',2)
        hold on
        if Ideal==1
            plot([0,Rezultati2(i).FiY,Rezultati2(i).FiMej],[0,Rezultati2(i).MY,Rezultati2(i).MY],'k--','LineWidth',2)
            scatter(Rezultati2(i).FiCC,Rezultati2(i).MCC,10,'k','o','LineWidth',2)
            scatter(Rezultati2(i).FiMej,Rezultati2(i).M1Mej,10,'k','v','LineWidth',2)
            scatter(Rezultati2(i).FiY1,Rezultati2(i).M1Y1,10,'k','s','LineWidth',2 )
            scatter(Rezultati2(i).FiY,Rezultati2(i).MY,10,'k','d','MarkerFaceColor','k','LineWidth',1 )
            scatter(Rezultati2(i).FiMej,Rezultati2(i).MY,10,'k','p','MarkerFaceColor','k','LineWidth',1 ) 
            hold on
        end
        if SupArm==1
            plot(fi2,Rezultati2(i).SigmaS*10^3,'k')
            plot(fi2,-Rezultati2(i).SigmaS2*10^3,'k:')
            hold on
        end
    end
        
        fi=Rezultati1(i).fi;
        fi(1)=[];
        % zveza med moemtnom in ukrivljenostjo iz analize prereza s uklonom
        Cur=Rezultati1(i).fi;
        M1=Rezultati1(i).M1;
        
        plot(Cur,M1,'LineWidth',2)
        hold on
        plot([min(Cur), max(Cur)],[0.8*max(M1),0.8*max(M1)])
        
        % --> KRITINE TOKE UKRIVLJENOSTI IZRAZENE IZ MERITEV
        % Dolzina plasticnega clenka [cm]
        Lpl=(0.1*BazaParametrov(i).L/1000+0.015*BazaParametrov(i).fiv/1000*BazaParametrov(i).fy)*100;
        L=BazaParametrov(i).L/10;
        % ukrivljenost na meji teenja armature izraena iz meritev zasuka na meji
        % teenja armature [1/cm]
        fiy=BazaParametrov(i).ThetaY*3*10/BazaParametrov(i).L;
        % mejna ukrivljenost prereza izraena iz izmerjenega mejnega zasuka [1/cm]
        fiu=(BazaParametrov(i).ThetaU+fiy*Lpl*(1-Lpl*10/(2*BazaParametrov(i).L)))/Lpl*(1-Lpl*10/(2*BazaParametrov(i).L));
        
        % --> POIE KORAK V ANALIZI PRI KATEREM JE ANALITINA UKRIVLJENOST
        %     NAJBLIJE IZMERJENI MEJNI UKRIVLJENOSTI
        KorakUp = find(Rezultati1(i).fi>fiu, 1, 'first');
        KorakLo = find(Rezultati1(i).fi<fiu, 1, 'first');
        if abs(Rezultati1(i).fi(KorakUp)-fiu)<abs(Rezultati1(i).fi(KorakLo)-fiu)
            Korak=KorakUp;
        else
            Korak=KorakLo;
        end
        
        % --> KRITINE TOKE UKRIVLJENOSTI IZRAZENE IZ ANALIZE
        % zasuk pri katerem se porui prvo vlakon v objetem betonu
        ind=find(Rezultati1(i).SigmaC9,1,'last');
        FiMej=Rezultati1(i).fi(ind+1);
        % zasuk kopri keterem stee jeklena armatura
        ind=find(Rezultati1(i).EpsS<BazaParametrov(i).fy/200000,1,'last');
        FiY=Rezultati1(i).fi(ind+1);
        
        % PLOT kritini zasuki meritev
        if KritToMer==1
            plot([fiy fiy], [0 max(M1)],'g')
            plot([fiu fiu], [0 max(M1)],'r')
            plot([Rezultati1(i).fi(Korak),Rezultati1(i).fi(Korak)],[0 max(M1)],'r:','LineWidth',3)
            hold on
        end
        % PLOT krotini zasuki analiza
        if KritToAnal==1
            plot([FiMej FiMej],[0 max(M1)],'r--')
            plot([FiY FiY],[0 max(M1)],'g--')
            hold on
        end
        % PLOT idealizirana zveza
        if Ideal==1
            plot([0,Rezultati1(i).FiY,Rezultati1(i).FiMej],[0,Rezultati1(i).MY,Rezultati1(i).MY],'r','LineWidth',2)
            scatter(Rezultati1(i).FiCC,Rezultati1(i).MCC,'b','o','LineWidth',2)
            scatter(Rezultati1(i).FiMej,Rezultati1(i).M1Mej,'b','v','LineWidth',2)
            scatter(Rezultati1(i).FiY1,Rezultati1(i).M1Y1,'b','s','LineWidth',2 )
            scatter(Rezultati1(i).FiY,Rezultati1(i).MY,'r','d','MarkerFaceColor','r','LineWidth',1 )
            scatter(Rezultati1(i).FiMej,Rezultati1(i).MY,'r','p','MarkerFaceColor','r','LineWidth',1 )
            hold on
        end
        
        % PLOT superpozicija napetosti v armaturi na zvezo M-Phi
        if SupArm==1
           
            plot(fi,Rezultati1(i).SigmaS*10^3,'Color','g')
            hold on
            plot(fi,-Rezultati1(i).SigmaS2*10^3,'r')
            hold on
            plot(fi,-Rezultati1(i).SigmaC9*10000,'m')
        end
        
        DiagramParameters('\phi [1/cm]','M[kNcm]',['i=' num2str(i) ', REF:' BazaParametrov(i).Reference '   TEST:' BazaParametrov(i).Test_ID '   \nu:' num2str(cell2mat(BazaParametrov(i).P)/(BazaParametrov(i).fc*BazaParametrov(i).b*BazaParametrov(i).h*0.001))])
    end


if CPhi==1
    % zveza med zasukom in vsemi napetostmi za 9 vlaken v betonskem jedru
    % rdea navpina linija oznauje zasuk, pri katerem se porui najbolj
    % tlaeno vlakno
    
    fi=Rezultati1(i).fi;
    fi(1)=[];
    cc=jet(9);
    figure
    plot(fi,Rezultati1(i).SigmaC1,'color',cc(1,:))
    hold on
    plot(fi,Rezultati1(i).SigmaC2,'color',cc(2,:))
    hold on
    plot(fi,Rezultati1(i).SigmaC3,'color',cc(3,:))
    hold on
    plot(fi,Rezultati1(i).SigmaC4,'color',cc(4,:))
    hold on
    plot(fi,Rezultati1(i).SigmaC5,'color',cc(5,:))
    hold on
    plot(fi,Rezultati1(i).SigmaC6,'color',cc(6,:))
    hold on
    plot(fi,Rezultati1(i).SigmaC7,'color',cc(7,:))
    hold on
    plot(fi,Rezultati1(i).SigmaC8,'color',cc(8,:))
    hold on
    plot(fi,Rezultati1(i).SigmaC9,'color',cc(9,:))
    hold on
    plot(fi,Rezultati1(i).SigmaCC,'r','LineWidth',2)
    hold on
    plot([FiMej FiMej],[0 min(Rezultati1(i).SigmaC9)],'r')
end

if APhi==1
    figure
    plot(fi,Rezultati1(i).SigmaS)
    hold on
    plot([FiY FiY],[0 max(Rezultati1(i).SigmaS)],'r')
end