
function [fcc,epscc,epscu]=objeti_beton(i,baza)
% VHODNI PODATKI IZ BAZE

% data in cm kN
epssu=0.1;
b=baza(i).b/10;          %- width of cros section cm
cpar=baza(i).cpar/10;    %- depth of the concrete cover parallel to loading force in cm
h=baza(i).h/10;          %- height of cross section in cm
cper=baza(i).cper/10;    %- depth of the concrete cover perpendicular to loading force in cm
fyh=baza(i).fyw/10;      %- yield strength of transverse reinforcement in kN/cm^2
fc=baza(i).fc/10;        %- concrete strength in kN/cm^2
row=baza(i).row;         %- transverse reinforcement ratio (Asw/(b*s))
fy=baza(i).fy/10;        %- tension in rebar at yielding in kN/cm^2
fu=baza(i).fsu/10;       %- ultimate sterength of longitudinal reinforcement [kN/cm^2]
N=cell2mat(baza(i).P);   %- loading force in kN
kev=baza(i).kev;         %- efficiency of concrete confinement in vertical direction
keh=baza(i).keh;         %- efficiency of concrete confinement in horizontal plane
ThetaY=baza(i).ThetaY;   %- measured rotation at yielding of reinfrocing steel
ThetaU=baza(i).ThetaU;   %- measured rotation at ultimate
L=baza(i).L/10;          %- lenght of canterliver [cm]
fiv=baza(i).fiv/10;      %- diameter od longitudinal reinforcement [cm]
s=baza(i).s/10;          %- distance between transverse reinforcement [cm]
rol=baza(i).rol;
%%%%%%%%%%%%%%%%%%%%%

% OCENA AMPLITUDE UKRIVLJENOSTI ZA ANALIZO NA PODLAGI KRITINIH ZASUKOV IZMERJENIH PRI EKSPERIMENTU

% Dolzina plasticnega clenka [cm]
Lpl=(0.1*L+0.015*fiv*fy*10);
%---------en:(3.11)--------%

% ukrivljenost na meji teenja armature izraena iz meritev zasuka na meji
% teenja armature [1/cm]
fiy=ThetaY*3/L;
%---------en:(3.9)--------%

% mejna ukrivljenost prereza izraena iz izmerjenega mejnega zasuka [1/cm]
fiu=(ThetaU+fiy*Lpl*(1-Lpl/(2*L)))/Lpl*(1-Lpl/(2*L));
%---------en:(3.10)--------%
%%%%%%%%%%%%%%%%%%%%%

% UKLONSKA DOLINA PALICE [cm]

lb=Uklonska_dolzina(i,baza)/10;
%%%%%%%%%%%%%%%%%%%%%

% LASTNOSTI OBJETEGA BETONA, ARMATURE IZPOSTAVLJENE UKLONU IN OSTALI PARAMETRI

d=h-cper;                                        % effective depth of tension reinforcement
ke=keh*kev;                                      % efficiency of concrete confinement
%---------en:(3.26)--------%
fl=row*ke*fyh;                                   % lateral pressure from transverse reinforcement [kN/cm^2] (Mander 1988, eq.:27)
%---------en:(3.20)--------%
fcc=fc*(2.254*(1+7.94*fl/fc)^0.5-2*fl/fc-1.254); % confined compressive strength [kN/cm^2]  (Mander 1988, eq.:29)
%---------en:(3.18)--------%
epscc=0.002*(1+5*(fcc/(fc)-1));                  % concrete strain at maximum resistance
%---------en:(3.18)--------%
Ec=500*(fc*10)^0.5;                              % tangent modulus of concrete elasticity [kN/cm^2] (Mander 1998, eq.:7)
%---------en:(3.19)--------%
epscu=0.004+1.4*epssu*(2*row*(fyh)/fcc);         % ultimate strain of confined concrete (Fardis 2003, eq.:7)
%---------en:(3.18)--------%
lsr=max(lb,s)/fiv;                               % senderness ratio
%---------en:(4.3)--------%
%%%%%%%%%%%%%%%%%%%%%

% ZAPIS VHODNE DATOTEKE "parameters.tcl" ZA OS

%Naredi file parameters.tcl
fileName='parameters.tcl';
%Odpre file parameters.tcl
fid=fopen(fileName,'wt');

%zapie parametre v file parameters
line='# Overall model\n';
fprintf(fid,line);
line=['set Ky ' num2str(fiu) '\n'];
fprintf(fid,line);
line=['set dj ' num2str(h-2*cper) '\n'];
fprintf(fid,line);
line='# Materials (concrete04)\n';
fprintf(fid,line);
line=['set fc ' num2str(-fcc) '\n'];
fprintf(fid,line);
line=['set ec ' num2str(-epscc) '\n'];
fprintf(fid,line);
line=['set ecu ' num2str(-epscu) '\n'];
fprintf(fid,line);
line=['set Ec ' num2str(Ec) '\n'];
fprintf(fid,line);
line='# Materials (concrete01)\n';
fprintf(fid,line);
line=['set fpc ' num2str(-fc) '\n'];
fprintf(fid,line);
line='set epsc0 -0.002\n';
fprintf(fid,line);
line='set fpcu -0\n';
fprintf(fid,line);
line='set epsU -0.0075\n';
fprintf(fid,line);
line='# Materials (ReinforcingSteel)\n';
fprintf(fid,line);
line='# -- basic\n';
fprintf(fid,line);
line=['set fy ' num2str(fy) '\n'];
fprintf(fid,line);
line=['set fu ' num2str(fu) '\n'];
fprintf(fid,line);
line='set Es 20000\n';
fprintf(fid,line);
line='set Esh 1500\n';
fprintf(fid,line);
line='set esh 0.01\n';
fprintf(fid,line);
line='set eult 0.2 \n';
fprintf(fid,line);
line=['set lsr ' num2str(lsr) '\n'];
fprintf(fid,line);
line='# Axcial force\n';
fprintf(fid,line);
line=['set P -' num2str(floor(N)) '\n'];
fprintf(fid,line);
%zapre file parameters.tcl
fclose(fid);
